diff --git a/src/tiscr.c b/src/tiscr.c
old mode 100644
new mode 100755
index 8da90bb..108b411
--- a/src/tiscr.c
+++ b/src/tiscr.c
@@ -25,6 +25,7 @@
 #include <errno.h>
 #include <glib/gstdio.h>
 #include "titools.h"
+#include <png.h>
 
 static gboolean full_screen = FALSE;
 static char *outfname = NULL;
@@ -36,11 +37,85 @@ static const GOptionEntry app_options[] =
      "Include invisible parts of screen buffer (TI-89 only)", NULL },
    { 0, 0, 0, 0, 0, 0, 0 }};
 
+void write_pgm(int height, int width, uint8_t *bitmap, FILE *f){
+  int bpr, i;
+  bpr = (width + 7) / 8;
+
+  fprintf(f, "P4\n%d %d\n", width, height);
+  for (i = 0; i < height; i++)
+  fwrite(bitmap + i * bpr, 1, bpr, f);
+  return;
+}
+
+void write_png(int height, int width, uint8_t *bitmap, FILE *f)
+{
+  int i;
+  png_structp png_ptr;
+  png_infop info_ptr;
+  png_bytep * row_pointers;
+  /* initialize stuff */
+  png_ptr = png_create_write_struct(PNG_LIBPNG_VER_STRING, NULL, NULL, NULL);
+
+  if (!png_ptr)
+    fprintf(stderr, "[write_png_file] png_create_write_struct failed");
+
+  info_ptr = png_create_info_struct(png_ptr);
+  if (!info_ptr)
+    fprintf(stderr, "[write_png_file] png_create_info_struct failed");
+
+  if (setjmp(png_jmpbuf(png_ptr)))
+    fprintf(stderr, "[write_png_file] Error during init_io");
+
+  png_init_io(png_ptr, f);
+
+
+  /* write header */
+  if (setjmp(png_jmpbuf(png_ptr)))
+    fprintf(stderr, "[write_png_file] Error during writing header");
+
+  png_set_IHDR(png_ptr, info_ptr, (uint8_t) width, (uint8_t) height,
+               1, PNG_COLOR_TYPE_GRAY, PNG_INTERLACE_NONE,
+               PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
+
+  png_write_info(png_ptr, info_ptr);
+ 
+  row_pointers = (png_bytep*) g_malloc(sizeof(png_bytep) * height);
+ 
+  /* Invert the bitmap because png's are backwards  from the calcs*/
+  for(i = 0; i < (height * width/8) ; i++) {
+    bitmap[i] = bitmap[i] ^ 0xFF;
+  }
+ 
+  /* Setup row_pointers, why doesn't libpng have a helper for this? */
+  for(i = 0; i < height; i++) {
+    row_pointers[i] = bitmap + i * width/8;
+  }
+
+  /* write bytes */
+  if (setjmp(png_jmpbuf(png_ptr)))
+    fprintf(stderr, "[write_png_file] Error during writing bytes");
+
+  png_write_image(png_ptr, row_pointers);
+
+
+  /* end write */
+  if (setjmp(png_jmpbuf(png_ptr)))
+    fprintf(stderr, "[write_png_file] Error during end of write");
+
+  png_write_end(png_ptr, NULL);
+
+  /* cleanup heap allocation */
+  //for (y=0; y<height; y++)
+    //gfree(row_pointers[y]);
+  g_free(row_pointers);
+}
+
+
 int main(int argc, char **argv)
 {
   CalcScreenCoord sc;
   uint8_t *bitmap = NULL;
-  int width, height, bpr, i, e;
+  int width, height, e;
   FILE *f;
 
   tt_init(argc, argv, app_options, 0, OPS_SCREEN, 1);
@@ -78,12 +153,9 @@ int main(int argc, char **argv)
     width = sc.clipped_width;
     height = sc.clipped_height;
   }
-
-  bpr = (width + 7) / 8;
-
-  fprintf(f, "P4\n%d %d\n", width, height);
-  for (i = 0; i < height; i++)
-    fwrite(bitmap + i * bpr, 1, bpr, f);
+  
+  //write_pgm(height, width, bitmap, f);
+  write_png(height, width, bitmap, f);
 
   if (f != stdout)
     fclose(f);
